Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(66)

Unified Diff: chrome/common/secure_origin_whitelist.cc

Issue 1124173007: Fix typo in --unsafely-treat-insecure-origin-as-secure (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/secure_origin_whitelist.h ('k') | chrome/common/secure_origin_whitelist_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/secure_origin_whitelist.cc
diff --git a/chrome/common/secure_origin_whitelist.cc b/chrome/common/secure_origin_whitelist.cc
index f5958572542d32dd5894f80b3893255fe4adf8ed..d8294a400362b17485babde65724d5ac36b7a2f0 100644
--- a/chrome/common/secure_origin_whitelist.cc
+++ b/chrome/common/secure_origin_whitelist.cc
@@ -11,16 +11,16 @@
#include "chrome/common/chrome_switches.h"
void GetSecureOriginWhitelist(std::set<GURL>* origins) {
// If kUnsafetyTreatInsecureOriginAsSecure option is given and
// kUserDataDir is present, add the given origins as trustworthy
// for whitelisting.
const base::CommandLine& command_line =
*base::CommandLine::ForCurrentProcess();
- if (command_line.HasSwitch(switches::kUnsafetyTreatInsecureOriginAsSecure) &&
+ if (command_line.HasSwitch(switches::kUnsafelyTreatInsecureOriginAsSecure) &&
command_line.HasSwitch(switches::kUserDataDir)) {
std::vector<std::string> given_origins;
base::SplitString(command_line.GetSwitchValueASCII(
- switches::kUnsafetyTreatInsecureOriginAsSecure), ',', &given_origins);
+ switches::kUnsafelyTreatInsecureOriginAsSecure), ',', &given_origins);
for (const auto& origin : given_origins)
origins->insert(GURL(origin));
}
@@ -11,16 +11,16 @@
#include "chrome/common/chrome_switches.h"
void GetSecureOriginWhitelist(std::set<GURL>* origins) {
- // If kUnsafetyTreatInsecureOriginAsSecure option is given and
+ // If kUnsafelyTreatInsecureOriginAsSecure option is given and
// kUserDataDir is present, add the given origins as trustworthy
// for whitelisting.
« no previous file with comments | « chrome/common/secure_origin_whitelist.h ('k') | chrome/common/secure_origin_whitelist_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698